@@ -189,6 +189,8 @@ func createTargetConfigController(c TargetConfigController, recorder events.Reco
 		"v4.1.0/kube-controller-manager/leader-election-kube-controller-manager-rolebinding-kube-system.yaml",
 		"v4.1.0/kube-controller-manager/svc.yaml",
 		"v4.1.0/kube-controller-manager/sa.yaml",
+		"v4.1.0/kube-controller-manager/gce/cloud-provider-role.yaml",
+		"v4.1.0/kube-controller-manager/gce/cloud-provider-binding.yaml",
 	)
 	for _, currResult := range directResourceResults {
 		if currResult.Error != nil {
