@@ -1,7 +1,8 @@
 package version
 
 import (
-	"github.com/prometheus/client_golang/prometheus"
+	"k8s.io/component-base/metrics"
+	"k8s.io/component-base/metrics/legacyregistry"
 
 	"k8s.io/apimachinery/pkg/version"
 )
@@ -34,8 +35,8 @@ func Get() version.Info {
 }
 
 func init() {
-	buildInfo := prometheus.NewGaugeVec(
-		prometheus.GaugeOpts{
+	buildInfo := metrics.NewGaugeVec(
+		&metrics.GaugeOpts{
 			Name: "openshift_cluster_kube_controller_manager_operator_build_info",
 			Help: "A metric with a constant '1' value labeled by major, minor, " +
 				"git commit & git version from which OpenShift Cluster Kube Controller Manager was built.",
@@ -44,5 +45,5 @@ func init() {
 	)
 	buildInfo.WithLabelValues(majorFromGit, minorFromGit, commitFromGit, versionFromGit).Set(1)
 
-	prometheus.MustRegister(buildInfo)
+	legacyregistry.MustRegister(buildInfo)
 }
